<?php

namespace Tests\Feature;

use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Support\Facades\Artisan;
use Illuminate\Support\Facades\Schema;
use Tests\TestCase;

class ModelSampleTest extends TestCase
{
    public function tearDown(): void
    {
        $migrations = glob(base_path('database/migrations/*'));
        foreach($migrations as $migration){
            if(is_file($migration)) {
                if (
                    str_contains($migration, 'bodies') ||
                    str_contains($migration, 'heads')
                ) {
                    unlink($migration);
                }
            }
        }
        Artisan::call('migrate:fresh');
        parent::tearDown();
    }

    public function test_command_one_to_one_relation()
    {
        $model1 = 'app/Models/Body.php';
        $model2 = 'app/Models/Head.php';
        if(is_file($model1)) {
            unlink($model1);
        }
        if(is_file($model2)) {
            unlink($model2);
        }
        Artisan::call('make:custom-model Body Head --type=11');
        Artisan::call('migrate:fresh');
        $this->assertTrue(file_exists(base_path($model1)));
        $this->assertTrue(file_exists(base_path($model2)));
        $this->assertTrue(Schema::hasTable('bodies'));
        $this->assertTrue(Schema::hasTable('heads'));
        unlink($model1);
        unlink($model2);
    }
}
